<p align="center">
  <img width="400" alt="Xata" src="https://raw.githubusercontent.com/xataio/xata-py/main/assets/logo_light.svg">
</p>

# Python SDK for Xata

[![Documentation Status](https://readthedocs.org/projects/xata-py/badge/?version=latest)](https://xata-py.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/xata.svg)](https://badge.fury.io/py/xata)

Xata is a serverless data platform, based on PostgreSQL. The data platform brings full-text search, vector similarity search, and file/image attachments on top of PostgreSQL. Xata supports also native database branches and a developer workflow that integrates seamlessly with GitHub and platforms like Vercel and Netlify.

The Python SDK uses type annotations and requires Python 3.8 or higher.

To install, run:

```
pip install xata
```

To learn more about Xata, visit [xata.io](https://xata.io).

- [SDK documentation](https://xata.io/docs/sdk/python/overview)
- [API Reference](https://xata-py.readthedocs.io/en/latest/api.html)
